@@ -2,8 +2,13 @@ from dataclasses import dataclass, field
 from datetime import datetime
 from abc import abstractmethod
 from ..const import NON_HOUR, CAUTION_HOUR, CHARGING_PERMITTED
+from ...timer.timer import Timer
+from ...scheduler.scheduler import Scheduler
 
 class Hours:
+    _timer: Timer
+    _scheduler: Scheduler
+
     def __init__(
             self,
             price_aware: bool,
@@ -27,6 +32,14 @@ class Hours:
     def price_aware(self) -> bool:
         return self._price_aware
 
+    @property
+    def timer(self) -> Timer:
+        return self._timer
+
+    @property
+    def scheduler(self) -> Scheduler:
+        return self._scheduler
+
     @property
     @abstractmethod
     def non_hours(self):
@@ -62,7 +75,7 @@ class Hours:
         pass
 
     @abstractmethod
-    def update_top_price(self, dyn_top_price) -> None: 
+    async def async_update_top_price(self, dyn_top_price) -> None: 
         pass
 
     @property
@@ -128,3 +141,12 @@ class Hours:
     @abstractmethod
     def adjusted_average(self, val):
         pass
+
+    @abstractmethod
+    async def async_get_average_kwh_price(self):
+        pass
+
+    @abstractmethod
+    async def async_get_total_charge(self):
+        pass
+    
\ No newline at end of file
