@@ -10,6 +10,18 @@ from ...models.const import (
 _LOGGER = logging.getLogger(__name__)
 
 
+ALGORITHM_INPUTS = {
+    "stop_caution": [1.075, 0.0032, 0.7],
+    "stop": [1.071, 0.00165, 0.8],
+    "start_caution": [1.081, 0.0049, 0.4],
+    "start": [1.066, 0.0045, 0.5]
+}
+
+def _calculate_algorithm_inputs(type:str, minute:int) -> float:
+    inputs = ALGORITHM_INPUTS[type]
+    return round((((minute+pow(inputs[0], minute)) * inputs[1]) + inputs[2]) * 100, 2)
+
+
 class ThresholdBase:
     BASECURRENT = 6
     def __init__(self, hub):
@@ -27,17 +39,21 @@ class ThresholdBase:
 
     @property
     def stop(self) -> float:
+        is_caution = str(datetime.now().hour) in self._hub.hours.caution_hours if self._hub.options.price.price_aware is False else False
+
         return ThresholdBase._stop(
             datetime.now().minute,
-            str(datetime.now().hour) in self._hub.hours.caution_hours if self._hub.options.price.price_aware is False else False,
+            is_caution,
             self._hub.sensors.locale.data.is_quarterly(self._hub.sensors.locale.data)
         )
 
     @property
     def start(self) -> float:
+        is_caution = str(datetime.now().hour) in self._hub.hours.caution_hours if self._hub.options.price.price_aware is False else False
+
         return ThresholdBase._start(
             datetime.now().minute,
-            str(datetime.now().hour) in self._hub.hours.caution_hours if self._hub.options.price.price_aware is False else False,
+            is_caution,
             self._hub.sensors.locale.data.is_quarterly(self._hub.sensors.locale.data)
         )
 
@@ -86,13 +102,10 @@ class ThresholdBase:
               is_caution_hour: bool,
               is_quarterly: bool=False
               ) -> float:
-        minute = _convert_quarterly_minutes(now_min, is_quarterly)
-        
+        minute = _convert_quarterly_minutes(now_min, is_quarterly) 
         if is_caution_hour and minute < 45:
-            ret = (((minute+pow(1.075, minute)) * 0.0032) + 0.7)
-        else:
-            ret = (((minute + pow(1.071, minute)) * 0.00165) + 0.8)
-        return round(ret * 100, 2)
+            return _calculate_algorithm_inputs("stop_caution", minute)
+        return _calculate_algorithm_inputs("stop", minute)
 
     @staticmethod
     def _start(
@@ -102,10 +115,8 @@ class ThresholdBase:
                ) -> float:
         minute = _convert_quarterly_minutes(now_min, is_quarterly)
         if is_caution_hour and minute < 45:
-            ret = (((minute+pow(1.081, minute)) * 0.0049) + 0.4)
-        else:
-            ret = (((minute + pow(1.066, minute)) * 0.0045) + 0.5)
-        return round(ret * 100, 2)
+            return _calculate_algorithm_inputs("start_caution", minute)
+        return _calculate_algorithm_inputs("start", minute)
     
     @staticmethod
     def allowed_current(
