@@ -2,7 +2,7 @@ from datetime import datetime
 import pytest
 
 from ..services.scheduler.scheduler import Scheduler
-from ..models.hourselection.hourselectionmodels import HourSelectionOptions
+from ..models.hourselection.hourselection_options import HourSelectionOptions
 
 MOCKPRICES = [0.422, 0.341, 0.309, 0.322, 0.331, 0.422, 0.773, 1.169, 1.794, 1.975, 2.119, 1.849, 1.309, 1.24, 1.137, 1.122, 1.14, 1.3, 1.397, 1.971, 1.377, 1.178, 1.05, 0.709]
 MOCKPRICES_TOMORROW = [0.513, 0.452, 0.458, 0.413, 0.377, 0.498, 0.693, 2.145, 2.193, 2.191, 2.184, 2.168, 2.153, 2.144, 2.135, 2.12, 2.134, 2.156, 2.165, 2.159, 2.146, 2.121, 2.081, 0.983]
